@@ -29,7 +29,7 @@
 # ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
 #
-# $Id: gen-avr-lib-tree.sh,v 1.12.2.14 2007/05/13 20:36:03 aesok Exp $
+# $Id: gen-avr-lib-tree.sh,v 1.12.2.26 2007/12/21 20:14:56 aesok Exp $
 #
 
 # This is a script to automate the generation of the avr/lib/ tree. Since
@@ -168,78 +168,96 @@ attiny45:crttn45.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
 attiny461:crttn461.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
 attiny84:crttn84.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
 attiny85:crttn85.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
-attiny861:crttn861.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS}\
+attiny861:crttn861.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+attiny43u:crttn43u.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+attiny48:crttn48.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+attiny88:crttn88.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS}\
 "
 
 AVR3_DEV_INFO="\
-atmega103:crtm103.o:${DEV_DEFS}:${CFLAGS_SPEED}:${DEV_ASFLAGS};\
-at43usb320:crt43320.o:${DEV_DEFS}:${CFLAGS_SPEED}:${DEV_ASFLAGS};\
-at43usb355:crt43355.o:${DEV_DEFS}:${CFLAGS_SPEED}:${DEV_ASFLAGS};\
-at76c711:crt76711.o:${DEV_DEFS}:${CFLAGS_SPEED}:${DEV_ASFLAGS}\
+atmega103:crtm103.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+at43usb320:crt43320.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+at43usb355:crt43355.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+at76c711:crt76711.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+at90usb82:crtusb82.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+at90usb162:crtusb162.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS}\
+"
+
+AVR35_DEV_INFO="\
+at90usb82:crtusb82.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+at90usb162:crtusb162.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS}\
 "
 
 AVR4_DEV_INFO="\
 atmega48:crtm48.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+atmega48p:crtm48p.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
 atmega8:crtm8.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
 atmega88:crtm88.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+atmega88p:crtm88p.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
 atmega8515:crtm8515.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
 atmega8535:crtm8535.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
 atmega8hva:crtm8hva.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
 at90pwm1:crt90pwm1.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
 at90pwm2:crt90pwm2.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
-at90pwm3:crt90pwm3.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS}\
+at90pwm2b:crt90pwm2b.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+at90pwm3:crt90pwm3.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+at90pwm3b:crt90pwm3b.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS}\
 "
 
 AVR5_DEV_INFO="\
-atmega16:crtm16.o:${DEV_DEFS}:${CFLAGS_SPEED}:${DEV_ASFLAGS};\
-atmega161:crtm161.o:${DEV_DEFS}:${CFLAGS_SPEED}:${DEV_ASFLAGS};\
-atmega162:crtm162.o:${DEV_DEFS}:${CFLAGS_SPEED}:${DEV_ASFLAGS};\
-atmega163:crtm163.o:${DEV_DEFS}:${CFLAGS_SPEED}:${DEV_ASFLAGS};\
-atmega164p:crtm164p.o:${DEV_DEFS}:${CFLAGS_SPEED}:${DEV_ASFLAGS};\
-atmega165:crtm165.o:${DEV_DEFS}:${CFLAGS_SPEED}:${DEV_ASFLAGS};\
-atmega165p:crtm165p.o:${DEV_DEFS}:${CFLAGS_SPEED}:${DEV_ASFLAGS};\
-atmega168:crtm168.o:${DEV_DEFS}:${CFLAGS_SPEED}:${DEV_ASFLAGS};\
-atmega169:crtm169.o:${DEV_DEFS}:${CFLAGS_SPEED}:${DEV_ASFLAGS};\
-atmega169p:crtm169p.o:${DEV_DEFS}:${CFLAGS_SPEED}:${DEV_ASFLAGS};\
-atmega16hva:crtm16hva.o:${DEV_DEFS}:${CFLAGS_SPEED}:${DEV_ASFLAGS};\
-atmega32:crtm32.o:${DEV_DEFS}:${CFLAGS_SPEED}:${DEV_ASFLAGS};\
-atmega323:crtm323.o:${DEV_DEFS}:${CFLAGS_SPEED}:${DEV_ASFLAGS};\
-atmega324p:crtm324p.o:${DEV_DEFS}:${CFLAGS_SPEED}:${DEV_ASFLAGS};\
-atmega325:crtm325.o:${DEV_DEFS}:${CFLAGS_SPEED}:${DEV_ASFLAGS};\
-atmega325p:crtm325p.o:${DEV_DEFS}:${CFLAGS_SPEED}:${DEV_ASFLAGS};\
-atmega3250:crtm3250.o:${DEV_DEFS}:${CFLAGS_SPEED}:${DEV_ASFLAGS};\
-atmega3250p:crtm3250p.o:${DEV_DEFS}:${CFLAGS_SPEED}:${DEV_ASFLAGS};\
-atmega329:crtm329.o:${DEV_DEFS}:${CFLAGS_SPEED}:${DEV_ASFLAGS};\
-atmega329p:crtm329p.o:${DEV_DEFS}:${CFLAGS_SPEED}:${DEV_ASFLAGS};\
-atmega3290:crtm3290.o:${DEV_DEFS}:${CFLAGS_SPEED}:${DEV_ASFLAGS};\
-atmega3290p:crtm3290p.o:${DEV_DEFS}:${CFLAGS_SPEED}:${DEV_ASFLAGS};\
-atmega406:crtm406.o:${DEV_DEFS}:${CFLAGS_SPEED}:${DEV_ASFLAGS};\
-atmega64:crtm64.o:${DEV_DEFS}:${CFLAGS_SPEED}:${DEV_ASFLAGS};\
-atmega640:crtm640.o:${DEV_DEFS}:${CFLAGS_SPEED}:${DEV_ASFLAGS};\
-atmega644:crtm644.o:${DEV_DEFS}:${CFLAGS_SPEED}:${DEV_ASFLAGS};\
-atmega644p:crtm644p.o:${DEV_DEFS}:${CFLAGS_SPEED}:${DEV_ASFLAGS};\
-atmega645:crtm645.o:${DEV_DEFS}:${CFLAGS_SPEED}:${DEV_ASFLAGS};\
-atmega6450:crtm6450.o:${DEV_DEFS}:${CFLAGS_SPEED}:${DEV_ASFLAGS};\
-atmega649:crtm649.o:${DEV_DEFS}:${CFLAGS_SPEED}:${DEV_ASFLAGS};\
-atmega6490:crtm6490.o:${DEV_DEFS}:${CFLAGS_SPEED}:${DEV_ASFLAGS};\
-atmega128:crtm128.o:${DEV_DEFS}:${CFLAGS_SPEED}:${DEV_ASFLAGS};\
-atmega1280:crtm1280.o:${DEV_DEFS}:${CFLAGS_SPEED}:${DEV_ASFLAGS};\
-atmega1281:crtm1281.o:${DEV_DEFS}:${CFLAGS_SPEED}:${DEV_ASFLAGS};\
-at90can32:crtcan32.o:${DEV_DEFS}:${CFLAGS_SPEED}:${DEV_ASFLAGS};\
-at90can64:crtcan64.o:${DEV_DEFS}:${CFLAGS_SPEED}:${DEV_ASFLAGS};\
-at90can128:crtcan128.o:${DEV_DEFS}:${CFLAGS_SPEED}:${DEV_ASFLAGS};\
-at90usb82:crtusb82.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
-at90usb162:crtusb162.o:${DEV_DEFS}:${CFLAGS_SPEED}:${DEV_ASFLAGS};\
-at90usb646:crtusb646.o:${DEV_DEFS}:${CFLAGS_SPEED}:${DEV_ASFLAGS};\
-at90usb647:crtusb647.o:${DEV_DEFS}:${CFLAGS_SPEED}:${DEV_ASFLAGS};\
-at90usb1286:crtusb1286.o:${DEV_DEFS}:${CFLAGS_SPEED}:${DEV_ASFLAGS};\
-at90usb1287:crtusb1287.o:${DEV_DEFS}:${CFLAGS_SPEED}:${DEV_ASFLAGS};\
-at94k:crtat94k.o:${DEV_DEFS}:${CFLAGS_SPEED}:${DEV_ASFLAGS}\
+atmega16:crtm16.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+atmega161:crtm161.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+atmega162:crtm162.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+atmega163:crtm163.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+atmega164p:crtm164p.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+atmega165:crtm165.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+atmega165p:crtm165p.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+atmega168:crtm168.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+atmega168p:crtm168p.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+atmega169:crtm169.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+atmega169p:crtm169p.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+atmega16hva:crtm16hva.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+atmega32:crtm32.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+atmega323:crtm323.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+atmega324p:crtm324p.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+atmega325:crtm325.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+atmega325p:crtm325p.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+atmega3250:crtm3250.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+atmega3250p:crtm3250p.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+atmega328p:crtm328p.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+atmega329:crtm329.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+atmega329p:crtm329p.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+atmega3290:crtm3290.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+atmega3290p:crtm3290p.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+atmega32hvb:crtm32hvb.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+atmega406:crtm406.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+atmega64:crtm64.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+atmega640:crtm640.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+atmega644:crtm644.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+atmega644p:crtm644p.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+atmega645:crtm645.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+atmega6450:crtm6450.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+atmega649:crtm649.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+atmega6490:crtm6490.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+atmega128:crtm128.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+atmega1280:crtm1280.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+atmega1281:crtm1281.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+atmega1284p:crtm1284p.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+at90can32:crtcan32.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+at90can64:crtcan64.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+at90can128:crtcan128.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+at90pwm216:crt90pwm216.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+at90pwm316:crt90pwm316.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+at90usb646:crtusb646.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+at90usb647:crtusb647.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+at90usb1286:crtusb1286.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+at90usb1287:crtusb1287.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+at94k:crtat94k.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS}\
 "
 
 AVR6_DEV_INFO="\
-atmega2560:crtm2560.o:${DEV_DEFS}:${CFLAGS_SPEED}:${DEV_ASFLAGS};\
-atmega2561:crtm2561.o:${DEV_DEFS}:${CFLAGS_SPEED}:${DEV_ASFLAGS}\
+atmega2560:crtm2560.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+atmega2561:crtm2561.o:${DEV_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS}\
 "
 
 LIB_DEFS="-D__COMPILING_AVR_LIBC__"
@@ -247,10 +265,11 @@ LIB_DEFS="-D__COMPILING_AVR_LIBC__"
 AVR_ARH_INFO="\
 avr2:AVR12_DEV_INFO:${LIB_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
 avr25:AVR25_DEV_INFO:${LIB_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
-avr3:AVR3_DEV_INFO:${LIB_DEFS}:${CFLAGS_SPEED}:${ASFLAGS_SPEED};\
+avr3:AVR3_DEV_INFO:${LIB_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+avr35:AVR35_DEV_INFO:${LIB_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
 avr4:AVR4_DEV_INFO:${LIB_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
-avr5:AVR5_DEV_INFO:${LIB_DEFS}:${CFLAGS_SPEED}:${DEV_ASFLAGS};\
-avr6:AVR6_DEV_INFO:${LIB_DEFS}:${CFLAGS_SPEED}:${DEV_ASFLAGS}\
+avr5:AVR5_DEV_INFO:${LIB_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS};\
+avr6:AVR6_DEV_INFO:${LIB_DEFS}:${CFLAGS_SPACE}:${DEV_ASFLAGS}\
 "
 
 echo "Generating source directories:"
@@ -260,11 +279,11 @@ ARH_SUBDIRS="SUBDIRS ="
 
 for ath_lib in $AVR_ARH_INFO
 do
-	arh=$(echo $ath_lib | awk -F: '{print $1}')
-	dev_info=$(echo $ath_lib | awk -F: '{print $2}')
-	lib_defs=$(echo $ath_lib | awk -F: '{print $3}')
-	lib_cflags=$(echo $ath_lib | awk -F: '{print $4}')
-	lib_asflags=$(echo $ath_lib | awk -F: '{print $5}')
+	arh=$(echo $ath_lib | cut -d ':' -f 1)
+	dev_info=$(echo $ath_lib | cut -d ':' -f 2)
+	lib_defs=$(echo $ath_lib | cut -d ':' -f 3)
+	lib_cflags=$(echo $ath_lib | cut -d ':' -f 4)
+	lib_asflags=$(echo $ath_lib | cut -d ':' -f 5)
 	
 	install_dir=$arh
 	if [ $arh = avr2 ]
@@ -285,11 +304,11 @@ do
 
 	for dev_crt in $DEV_INFO
 	do
-		dev=$(echo $dev_crt | awk -F: '{print $1}')
-		crt=$(echo $dev_crt | awk -F: '{print $2}')
-		crt_defs=$(echo $dev_crt | awk -F: '{print $3}')
-		crt_cflags=$(echo $dev_crt | awk -F: '{print $4}')
-		crt_asflags=$(echo $dev_crt | awk -F: '{print $5}')
+		dev=$(echo $dev_crt | cut -d ':' -f 1)
+		crt=$(echo $dev_crt | cut -d ':' -f 2)
+		crt_defs=$(echo $dev_crt | cut -d ':' -f 3)
+		crt_cflags=$(echo $dev_crt | cut -d ':' -f 4)
+		crt_asflags=$(echo $dev_crt | cut -d ':' -f 5)
 		
 		echo "  avr/lib/$arh/$dev"
 		
