@@ -1,4 +1,5 @@
 /* Copyright (c) 2002,2003,2005,2006,2007 Marek Michalkiewicz, Joerg Wunsch
+   Copyright (c) 2007 Eric B. Weddington
    All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
@@ -28,7 +29,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: io.h,v 1.24.2.17 2007/05/13 20:36:03 aesok Exp $ */
+/* $Id: io.h,v 1.24.2.27 2007/11/29 22:37:43 arcanum Exp $ */
 
 /** \file */
 /** \defgroup avr_io <avr/io.h>: AVR device-specific IO definitions
@@ -39,16 +40,22 @@
     command-line switch.  This is done by diverting to the appropriate
     file <tt>&lt;avr/io</tt><em>XXXX</em><tt>.h&gt;</tt> which should
     never be included directly.  Some register names common to all
-    AVR devices are defined directly within <tt>&lt;avr/io.h&gt;</tt>,
+    AVR devices are defined directly within <tt>&lt;avr/common.h&gt;</tt>,
+    which is included in <tt>&lt;avr/io.h&gt;</tt>,
     but most of the details come from the respective include file.
 
-    Note that this file always includes
-    \code #include <avr/sfr_defs.h> \endcode
-    See \ref avr_sfr for the details.
+    Note that this file always includes the following files:
+    \code 
+    #include <avr/sfr_defs.h>
+    #include <avr/portpins.h>
+    #include <avr/common.h>
+    #include <avr/version.h>
+    \endcode
+    See \ref avr_sfr for more details about that header file.
 
     Included are definitions of the IO register set and their
     respective bit values as specified in the Atmel documentation.
-    Note that Atmel is not very consistent in its naming conventions,
+    Note that inconsistencies in naming conventions,
     so even identical functions sometimes get different names on
     different devices.
 
@@ -86,94 +93,6 @@
 
 #include <avr/sfr_defs.h>
 
-#ifndef __AVR_HAVE_MOVW__
-#  if  defined(__AVR_ENHANCED__) && __AVR_ENHANCED__
-#   define __AVR_HAVE_MOVW__ 1
-#  endif
-#endif
-
-#ifndef __AVR_HAVE_LPMX__
-# if  defined(__AVR_ENHANCED__) && __AVR_ENHANCED__
-#  define __AVR_HAVE_LPMX__ 1
-# endif
-#endif
-
-/*
- * Registers common to all AVR devices.
- */
-
-#if __AVR_ARCH__ != 1
-/*
- * AVR architecture 1 has no RAM, thus no stack pointer.
- *
- * All other archs do have a stack pointer.  Some devices have only
- * less than 256 bytes of possible RAM locations (128 Bytes of SRAM
- * and no option for external RAM), thus SPH is officially "reserved"
- * for them.  We catch this case below after including the
- * device-specific ioXXXX.h file, by examining XRAMEND, and
- * #undef-ining SP and SPH in that case.
- */
-/* Stack Pointer */
-#define SP        _SFR_IO16(0x3D)
-#define SPL       _SFR_IO8(0x3D)
-#define SPH       _SFR_IO8(0x3E)
-#endif /* #if __AVR_ARCH__ != 1 */
-
-/* Status REGister */
-#define SREG      _SFR_IO8(0x3F)
-
-/* Status Register - SREG */
-#define    SREG_I       7
-#define    SREG_T       6
-#define    SREG_H       5
-#define    SREG_S       4
-#define    SREG_V       3
-#define    SREG_N       2
-#define    SREG_Z       1
-#define    SREG_C       0
-
-/* Pointer definition */
-#if __AVR_ARCH__ != 1
-/* avr1 has only the Z pointer */
-#define    XL           r26
-#define    XH           r27
-#define    YL           r28
-#define    YH           r29
-#endif /* #if __AVR_ARCH__ != 1 */
-#define    ZL           r30
-#define    ZH           r31
-
-/*
- * Only few devices come without EEPROM.  In order to assemble the
- * EEPROM library components without defining a specific device, we
- * keep the EEPROM-related definitions here.
- */
-#if defined(__COMPILING_AVR_LIBC__)
-
-/* EEPROM Control Register */
-#define EECR	_SFR_IO8(0x1C)
-
-/* EEPROM Data Register */
-#define EEDR	_SFR_IO8(0x1D)
-
-/* EEPROM Address Register */
-#define EEAR	_SFR_IO16(0x1E)
-#define EEARL	_SFR_IO8(0x1E)
-#define EEARH	_SFR_IO8(0x1F)
-
-/* EEPROM Control Register */
-#define    EERIE        3
-#define    EEMWE        2
-#define    EEWE         1
-#define    EERE         0
-
-/* Extended indirect addressing of ATmega256x devices */
-#if __AVR_ARCH__ == 6
-#  define EIND     _SFR_IO8(0X3C)
-#endif
-
-#endif /* __COMPILING_AVR_LIBC__ */
-
 #if defined (__AVR_AT94K__)
 #  include <avr/ioat94k.h>
 #elif defined (__AVR_AT43USB320__)
@@ -188,14 +107,24 @@
 #  include <avr/io90pwm1.h>
 #elif defined (__AVR_AT90PWM2__)
 #  include <avr/io90pwmx.h>
+#elif defined (__AVR_AT90PWM2B__)
+#  include <avr/io90pwm2b.h>
 #elif defined (__AVR_AT90PWM3__)
 #  include <avr/io90pwmx.h>
+#elif defined (__AVR_AT90PWM3B__)
+#  include <avr/io90pwm3b.h>
+#elif defined (__AVR_AT90PWM216__)
+#  include <avr/io90pwm216.h>
+#elif defined (__AVR_AT90PWM316__)
+#  include <avr/io90pwm316.h>
 #elif defined (__AVR_ATmega128__)
 #  include <avr/iom128.h>
 #elif defined (__AVR_ATmega1280__)
 #  include <avr/iom1280.h>
 #elif defined (__AVR_ATmega1281__)
 #  include <avr/iom1281.h>
+#elif defined (__AVR_ATmega1284P__)
+#  include <avr/iom1284p.h>
 #elif defined (__AVR_ATmega2560__)
 #  include <avr/iom2560.h>
 #elif defined (__AVR_ATmega2561__)
@@ -250,6 +179,8 @@
 #  include <avr/iom3250.h>
 #elif defined (__AVR_ATmega3250P__)
 #  include <avr/iom3250.h>
+#elif defined (__AVR_ATmega328P__)
+#  include <avr/iom328p.h>
 #elif defined (__AVR_ATmega329__)
 #  include <avr/iom329.h>
 #elif defined (__AVR_ATmega329P__)
@@ -258,6 +189,8 @@
 #  include <avr/iom3290.h>
 #elif defined (__AVR_ATmega3290P__)
 #  include <avr/iom3290.h>
+#elif defined (__AVR_ATmega32HVB__)
+#  include <avr/iom32hvb.h>
 #elif defined (__AVR_ATmega406__)
 #  include <avr/iom406.h>
 #elif defined (__AVR_ATmega16__)
@@ -276,6 +209,8 @@
 #  include <avr/iom165p.h>
 #elif defined (__AVR_ATmega168__)
 #  include <avr/iom168.h>
+#elif defined (__AVR_ATmega168P__)
+#  include <avr/iom168p.h>
 #elif defined (__AVR_ATmega169__)
 #  include <avr/iom169.h>
 #elif defined (__AVR_ATmega169P__)
@@ -288,8 +223,12 @@
 #  include <avr/iom8.h>
 #elif defined (__AVR_ATmega48__)
 #  include <avr/iom48.h>
+#elif defined (__AVR_ATmega48P__)
+#  include <avr/iom48p.h>
 #elif defined (__AVR_ATmega88__)
 #  include <avr/iom88.h>
+#elif defined (__AVR_ATmega88P__)
+#  include <avr/iom88p.h>
 #elif defined (__AVR_ATmega8515__)
 #  include <avr/iom8515.h>
 #elif defined (__AVR_ATmega8535__)
@@ -340,6 +279,12 @@
 #  include <avr/iotn461.h>
 #elif defined (__AVR_ATtiny861__)
 #  include <avr/iotn861.h>
+#elif defined (__AVR_ATtiny43U__)
+#  include <avr/iotn43u.h>
+#elif defined (__AVR_ATtiny48__)
+#  include <avr/iotn48.h>
+#elif defined (__AVR_ATtiny88__)
+#  include <avr/iotn88.h>
 /* avr1: the following only supported for assembler programs */
 #elif defined (__AVR_ATtiny28__)
 #  include <avr/iotn28.h>
@@ -359,14 +304,14 @@
 
 #include <avr/portpins.h>
 
-#if __AVR_ARCH__ != 1
-#  if XRAMEND < 0x100 && !defined(__COMPILING_AVR_LIBC__)
-#    undef SP
-#    define SP     _SFR_IO8(0x3D)
-#    undef SPH
-#  endif
-#endif
+#include <avr/common.h>
 
 #include <avr/version.h>
 
+/* Include fuse.h after individual IO header files. */
+#include <avr/fuse.h>
+
+/* Include lock.h after individual IO header files. */
+#include <avr/lock.h>
+
 #endif /* _AVR_IO_H_ */
