@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: io90pwm316.h,v 1.1.2.2 2007/10/08 22:37:10 arcanum Exp $ */
+/* $Id: io90pwm316.h,v 1.1.2.6 2007/12/19 00:29:17 arcanum Exp $ */
 
 /* avr/io90pwm316.h - definitions for AT90PWM316 */
 
@@ -906,6 +906,10 @@
 
 /* PSC 1 Synchro and Output Configuration */
 #define PSOC1   _SFR_MEM8(0xE0)
+#define POEN1A 0
+#define POEN1B 2
+#define PSYNC1 4
+#define PSYNC1 5
 
 /* Output Compare SA Registers */
 #define OCR1SA  _SFR_MEM16(0xE2)
@@ -1155,16 +1159,17 @@
 /* Store Program Memory Read */
 #define SPM_READY_vect     _VECTOR(31)
 
-#define _VECTORS_SIZE   64
+#define _VECTORS_SIZE   (4 * 32)
 
 /* Constants */
 
-#define RAMEND         0x3FF
+#define RAMEND         0x4FF
 #define XRAMEND        0
 #define E2END          0x1FF
 #define FLASHEND       0x3FFF
 #define SPM_PAGESIZE   128
 
+
 /* Fuse Information */
 
 #define FUSE_MEMORY_SIZE 3
@@ -1178,23 +1183,34 @@
 #define SUT1    ~_BV(5)  /* Select start-up time */
 #define CKOUT   ~_BV(6)  /* Oscillator output option */
 #define CKDIV8  ~_BV(7)  /* Divide clock by 8 */
-#define LFUSE_DEFAULT (CKSEL1 & CKSEL2 & CKSEL3 & SUT0 & SUT1 & CKDIV8)
+#define LFUSE_DEFAULT (CKSEL0 & CKSEL2 & CKSEL3 & SUT0 & CKDIV8)
 
 /* High Fuse Byte */
+#define BODLEVEL0 ~_BV(0)
+#define BODLEVEL1 ~_BV(1)
+#define BODLEVEL2 ~_BV(2)
+#define EESAVE    ~_BV(3)  /* EEPROM memory is preserved through chip erase */
+#define WDTON     ~_BV(4)  /* Watchdog timer always on */
+#define SPIEN     ~_BV(5)  /* Enable Serial programming and Data Downloading */
+#define DWEN      ~_BV(6)  /* debugWIRE Enable */
+#define RSTDISBL  ~_BV(7)  /* External Reset Diasble */
+#define HFUSE_DEFAULT (SPIEN)
+
+/* Extended Fuse Byte */
 #define BOOTRST  ~_BV(0)  /* Select Reset Vector */
 #define BOOTSZ0  ~_BV(1)  /* Select Boot Size */
 #define BOOTSZ1  ~_BV(2)  /* Select Boot Size */
-#define EESAVE   ~_BV(3)  /* EEPROM memory is preserved through chip erase */
-#define WDTON    ~_BV(4)  /* Watchdog timer always on */
-#define SPIEN    ~_BV(5)  /* Enable Serial programming and Data Downloading */
-#define DWEN     ~_BV(6)  /* debugWIRE Enable */
-#define RSTDISBL ~_BV(7)  /* External Reset Diasble */
-#define HFUSE_DEFAULT (BOOTSZ0 & BOOTSZ1 & SPIEN)
+#define PSCRV    ~_BV(4)
+#define PSC0RB   ~_BV(5)
+#define PSC1RB   ~_BV(6)
+#define PSC2RB   ~_BV(7)
+#define EFUSE_DEFAULT (BOOTSZ0 & BOOTSZ1)
+
+
+/* Lock Bits */
+#define __LOCK_BITS_EXIST
+#define __BOOT_LOCK_BITS_0_EXIST
+#define __BOOT_LOCK_BITS_1_EXIST 
 
-/* Extended Fuse Byte */
-#define BODLEVEL0 ~_BV(1)
-#define BODLEVEL1 ~_BV(2)
-#define BODLEVEL2 ~_BV(3)
-#define EFUSE_DEFAULT (0xFF)
 
 #endif /* _AVR_IO90PWM316_H_ */
