@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: io90pwmx.h,v 1.6.2.2 2007/05/06 15:43:50 arcanum Exp $ */
+/* $Id: io90pwmx.h,v 1.6.2.4 2007/12/12 04:39:24 arcanum Exp $ */
 
 /* avr/io90pwmx.h - definitions for AT90PWM2(B) and AT90PWM3(B) */
 
@@ -535,9 +535,21 @@
 
 /* Amplifier 0 Control and Status register */
 #define AMP0CSR _SFR_MEM8(0x76)
+#define AMP0EN  7
+#define AMP0IS  6
+#define AMP0G1  5
+#define AMP0G0  4
+#define AMP0TS1 1
+#define AMP0TS0 0
 
 /* Amplifier 1 Control and Status register */
 #define AMP1CSR _SFR_MEM8(0x77)
+#define AMP1EN  7
+#define AMP1IS  6
+#define AMP1G1  5
+#define AMP1G0  4
+#define AMP1TS1 1
+#define AMP1TS0 0
 
 /* ADC Result Data Register */
 #ifndef __ASSEMBLER__
@@ -563,6 +575,7 @@
 #define ADCSRB  _SFR_MEM8(0x7B)
 /* ADCSRB */
 #define ADHSM   7   /* ADC High Speed Mode */
+#define ADASCR  4
 #define ADTS3   3   /* ADC Auto Trigger Source 3 */
 #define ADTS2   2   /* ADC Auto Trigger Source 2 */
 #define ADTS1   1   /* ADC Auto Trigger Source 1 */
@@ -1310,4 +1323,48 @@
 #define E2END       0x01FF
 #define FLASHEND    0x0FFF
 
+
+/* Fuse Information */
+
+#define FUSE_MEMORY_SIZE 3
+
+/* Low Fuse Byte */
+#define CKSEL0  ~_BV(0)  /* Select Clock Source */
+#define CKSEL1  ~_BV(1)  /* Select Clock Source */
+#define CKSEL2  ~_BV(2)  /* Select Clock Source */
+#define CKSEL3  ~_BV(3)  /* Select Clock Source */
+#define SUT0    ~_BV(4)  /* Select start-up time */
+#define SUT1    ~_BV(5)  /* Select start-up time */
+#define CKOUT   ~_BV(6)  /* Oscillator output option */
+#define CKDIV8  ~_BV(7)  /* Divide clock by 8 */
+#define LFUSE_DEFAULT (CKSEL0 & CKSEL2 & CKSEL3 & SUT0 & CKDIV8)
+
+/* High Fuse Byte */
+#define BODLEVEL0  ~_BV(0)
+#define BODLEVEL1  ~_BV(1)
+#define BODLEVEL2  ~_BV(2)
+#define EESAVE     ~_BV(3)  /* EEPROM memory is preserved through chip erase */
+#define WDTON      ~_BV(4)  /* Watchdog timer always on */
+#define SPIEN      ~_BV(5)  /* Enable Serial programming and Data Downloading */
+#define DWEN       ~_BV(6)  /* debugWIRE Enable */
+#define RSTDISBL   ~_BV(7)  /* External Reset Diasble */
+#define HFUSE_DEFAULT (SPIEN)
+
+/* Extended Fuse Byte */
+#define BOOTRST     ~_BV(0)
+#define BOOTSZ0     ~_BV(1)
+#define BOOTSZ1     ~_BV(2)
+#define PSCRV       ~_BV(4)
+#define PSC0RB      ~_BV(5)
+#define PSC1RB      ~_BV(6)
+#define PSC2RB      ~_BV(7)
+#define EFUSE_DEFAULT (BOOTSZ0 & BOOTSZ1)
+
+
+/* Lock Bits */
+#define __LOCK_BITS_EXIST
+#define __BOOT_LOCK_BITS_0_EXIST
+#define __BOOT_LOCK_BITS_1_EXIST 
+
+
 #endif /* _AVR_IO90PWMX_H_ */
