@@ -1,6 +1,6 @@
 /* Copyright (c) 2002, 2003, 2004, 2005 
    Juergen Schilling <juergen.schilling@honeywell.com>
-   Eric B. Weddington <ericw@evcohs.com>
+   Eric B. Weddington
    All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
@@ -30,7 +30,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iom169.h,v 1.24 2005/10/30 22:11:23 joerg_wunsch Exp $ */
+/* $Id: iom169.h,v 1.24.2.2 2007/12/12 04:39:26 arcanum Exp $ */
 
 /* iom169.h - definitions for ATmega169 */
 
@@ -989,6 +989,8 @@
 #define LCDAB  6
 #define LCDIF  4
 #define LCDIE  3
+#define LCDBD  2 /* Only in Rev. F */
+#define LCDCCD 1 /* Only in Rev. F */
 #define LCDBL  0
 
 /* LCDCRB */
@@ -1012,7 +1014,7 @@
 #define LCDDC2 7
 #define LCDDC1 6
 #define LCDDC0 5
-#define LCDMDT 4
+#define LCDMDT 4 /* Only in Rev. F */
 #define LCDCC3 3
 #define LCDCC2 2
 #define LCDCC1 1
@@ -1055,4 +1057,44 @@
 #define E2END		0x1FF
 #define FLASHEND	0x3FFF
 
+
+/* Fuses */
+
+#define FUSE_MEMORY_SIZE 3
+
+/* Low Fuse Byte */
+#define CKSEL0      ~_BV(0)
+#define CKSEL1      ~_BV(1)
+#define CKSEL2      ~_BV(2)
+#define CKSEL3      ~_BV(3)
+#define SUT0        ~_BV(4)
+#define SUT1        ~_BV(5)
+#define CKOUT       ~_BV(6)
+#define CKDIV8      ~_BV(7)
+#define LFUSE_DEFAULT (CKSEL0 & CKSEL2 & CKSEL3 & SUT0 & CKDIV8)
+
+/* High Fuse Byte */
+#define BOOTRST     ~_BV(0)
+#define BOOTSZ0     ~_BV(1)
+#define BOOTSZ1     ~_BV(2)
+#define EESAVE      ~_BV(3)
+#define WDTON       ~_BV(4)
+#define SPIEN       ~_BV(5)
+#define JTAGEN      ~_BV(6)
+#define OCDEN       ~_BV(7)
+#define HFUSE_DEFAULT (BOOTSZ0 & BOOTSZ1 & SPIEN & JTAGEN)
+
+/* Extended Fuse Byte */
+#define BODLEVEL0   ~_BV(1)
+#define BODLEVEL1   ~_BV(2)
+#define BODLEVEL2   ~_BV(3)
+#define EFUSE_DEFAULT (0xFF)
+
+
+/* Lock Bits */
+#define __LOCK_BITS_EXIST
+#define __BOOT_LOCK_BITS_0_EXIST
+#define __BOOT_LOCK_BITS_1_EXIST 
+
+
 #endif  /* _AVR_IOM169_H_ */
