@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iom32.h,v 1.7.2.1 2005/07/19 15:02:13 aesok Exp $ */
+/* $Id: iom32.h,v 1.10.2.1 2007/12/12 04:39:26 arcanum Exp $ */
 
 /* avr/iom32.h - definitions for ATmega32 */
 
@@ -170,29 +170,88 @@
 
 /* Interrupt vectors */
 
-#define SIG_INTERRUPT0          _VECTOR(1)
-#define SIG_INTERRUPT1          _VECTOR(2)
-#define SIG_INTERRUPT2          _VECTOR(3)
-#define SIG_OUTPUT_COMPARE2     _VECTOR(4)
-#define SIG_OVERFLOW2           _VECTOR(5)
-#define SIG_INPUT_CAPTURE1      _VECTOR(6)
-#define SIG_OUTPUT_COMPARE1A    _VECTOR(7)
-#define SIG_OUTPUT_COMPARE1B    _VECTOR(8)
-#define SIG_OVERFLOW1           _VECTOR(9)
-#define SIG_OUTPUT_COMPARE0     _VECTOR(10)
-#define SIG_OVERFLOW0           _VECTOR(11)
-#define SIG_SPI                 _VECTOR(12)
-#define SIG_USART_RECV          _VECTOR(13)
-#define SIG_UART_RECV           _VECTOR(13) /* For backwards compatibility */
-#define SIG_USART_DATA          _VECTOR(14)
-#define SIG_UART_DATA           _VECTOR(14) /* For backwards compatibility */
-#define SIG_USART_TRANS         _VECTOR(15)
-#define SIG_UART_TRANS          _VECTOR(15) /* For backwards compatibility */
-#define SIG_ADC                 _VECTOR(16)
-#define SIG_EEPROM_READY        _VECTOR(17)
-#define SIG_COMPARATOR          _VECTOR(18)
-#define SIG_2WIRE_SERIAL        _VECTOR(19)
-#define SIG_SPM_READY           _VECTOR(20)
+/* External Interrupt Request 0 */
+#define INT0_vect			_VECTOR(1)
+#define SIG_INTERRUPT0			_VECTOR(1)
+
+/* External Interrupt Request 1 */
+#define INT1_vect			_VECTOR(2)
+#define SIG_INTERRUPT1			_VECTOR(2)
+
+/* External Interrupt Request 2 */
+#define INT2_vect			_VECTOR(3)
+#define SIG_INTERRUPT2			_VECTOR(3)
+
+/* Timer/Counter2 Compare Match */
+#define TIMER2_COMP_vect		_VECTOR(4)
+#define SIG_OUTPUT_COMPARE2		_VECTOR(4)
+
+/* Timer/Counter2 Overflow */
+#define TIMER2_OVF_vect			_VECTOR(5)
+#define SIG_OVERFLOW2			_VECTOR(5)
+
+/* Timer/Counter1 Capture Event */
+#define TIMER1_CAPT_vect		_VECTOR(6)
+#define SIG_INPUT_CAPTURE1		_VECTOR(6)
+
+/* Timer/Counter1 Compare Match A */
+#define TIMER1_COMPA_vect		_VECTOR(7)
+#define SIG_OUTPUT_COMPARE1A		_VECTOR(7)
+
+/* Timer/Counter1 Compare Match B */
+#define TIMER1_COMPB_vect		_VECTOR(8)
+#define SIG_OUTPUT_COMPARE1B		_VECTOR(8)
+
+/* Timer/Counter1 Overflow */
+#define TIMER1_OVF_vect			_VECTOR(9)
+#define SIG_OVERFLOW1			_VECTOR(9)
+
+/* Timer/Counter0 Compare Match */
+#define TIMER0_COMP_vect		_VECTOR(10)
+#define SIG_OUTPUT_COMPARE0		_VECTOR(10)
+
+/* Timer/Counter0 Overflow */
+#define TIMER0_OVF_vect			_VECTOR(11)
+#define SIG_OVERFLOW0			_VECTOR(11)
+
+/* Serial Transfer Complete */
+#define SPI_STC_vect			_VECTOR(12)
+#define SIG_SPI				_VECTOR(12)
+
+/* USART, Rx Complete */
+#define USART_RXC_vect			_VECTOR(13)
+#define SIG_USART_RECV			_VECTOR(13)
+#define SIG_UART_RECV			_VECTOR(13)
+
+/* USART Data Register Empty */
+#define USART_UDRE_vect			_VECTOR(14)
+#define SIG_USART_DATA			_VECTOR(14)
+#define SIG_UART_DATA			_VECTOR(14)
+
+/* USART, Tx Complete */
+#define USART_TXC_vect			_VECTOR(15)
+#define SIG_USART_TRANS			_VECTOR(15)
+#define SIG_UART_TRANS			_VECTOR(15)
+
+/* ADC Conversion Complete */
+#define ADC_vect			_VECTOR(16)
+#define SIG_ADC				_VECTOR(16)
+
+/* EEPROM Ready */
+#define EE_RDY_vect			_VECTOR(17)
+#define SIG_EEPROM_READY		_VECTOR(17)
+
+/* Analog Comparator */
+#define ANA_COMP_vect			_VECTOR(18)
+#define SIG_COMPARATOR			_VECTOR(18)
+
+/* 2-wire Serial Interface */
+#define TWI_vect			_VECTOR(19)
+#define SIG_2WIRE_SERIAL		_VECTOR(19)
+
+/* Store Program Memory Ready */
+#define SPM_RDY_vect			_VECTOR(20)
+#define SIG_SPM_READY			_VECTOR(20)
 
 #define _VECTORS_SIZE 84
 
@@ -593,4 +652,38 @@
 #define E2END       0x3FF
 #define FLASHEND    0x7FFF
 
+
+/* Fuses */
+
+#define FUSE_MEMORY_SIZE 2
+
+/* Low Fuse Byte */
+#define CKSEL0      ~_BV(0)
+#define CKSEL1      ~_BV(1)
+#define CKSEL2      ~_BV(2)
+#define CKSEL3      ~_BV(3)
+#define SUT0        ~_BV(4)
+#define SUT1        ~_BV(5)
+#define BODEN       ~_BV(6)
+#define BODLEVEL    ~_BV(7)
+#define LFUSE_DEFAULT (CKSEL1 & CKSEL2 & CKSEL3 & SUT0)
+
+/* High Fuse Byte */
+#define BOOTRST     ~_BV(0)
+#define BOOTSZ0     ~_BV(1)
+#define BOOTSZ1     ~_BV(2)
+#define EESAVE      ~_BV(3)
+#define CKOPT       ~_BV(4)
+#define SPIEN       ~_BV(5)
+#define JTAGEN      ~_BV(6)
+#define OCDEN       ~_BV(7)
+#define HFUSE_DEFAULT (BOOTSZ0 & BOOTSZ1 & SPIEN & JTAGEN)
+
+
+/* Lock Bits */
+#define __LOCK_BITS_EXIST
+#define __BOOT_LOCK_BITS_0_EXIST
+#define __BOOT_LOCK_BITS_1_EXIST 
+
+
 #endif /* _AVR_IOM32_H_ */
