@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iotn12.h,v 1.9 2005/11/10 22:19:07 joerg_wunsch Exp $ */
+/* $Id: iotn12.h,v 1.9.2.1 2007/12/12 04:39:28 arcanum Exp $ */
 
 /* avr/iotn12.h - definitions for ATtiny12 */
 
@@ -234,4 +234,25 @@
 #define E2END		0x3F
 #define FLASHEND	0x3FF
 
+
+/* Fuses */
+
+#define FUSE_MEMORY_SIZE 1
+
+/* Low Fuse Byte */
+#define CKSEL0      ~_BV(0)
+#define CKSEL1      ~_BV(1)
+#define CKSEL2      ~_BV(2)
+#define CKSEL3      ~_BV(3)
+#define RSTDISBL    ~_BV(4)
+#define SPIEN       ~_BV(5)
+#define BODEN       ~_BV(6)
+#define BODLEVEL    ~_BV(7)
+#define FUSE_DEFAULT (CKSEL0 & CKSEL2 & CKSEL3 & SPIEN & BODLEVEL)
+
+
+/* Lock Bits */
+#define __LOCK_BITS_EXIST
+
+
 #endif /* _AVR_IOTN12_H_ */
