@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iotn2313.h,v 1.9.2.4 2007/01/22 23:27:45 joerg_wunsch Exp $ */
+/* $Id: iotn2313.h,v 1.9.2.5 2007/12/12 04:39:28 arcanum Exp $ */
 
 /* iotn2313.h derived from io2313.h by Bob Paddock.
 
@@ -588,4 +588,40 @@
 #define FLASHEND  0x07FF
 #define SPM_PAGESIZE    32
 
+
+/* Fuses */
+
+#define FUSE_MEMORY_SIZE 3
+
+/* Low Fuse Byte */
+#define CKSEL0      ~_BV(0)
+#define CKSEL1      ~_BV(1)
+#define CKSEL2      ~_BV(2)
+#define CKSEL3      ~_BV(3)
+#define SUT0        ~_BV(4)
+#define SUT1        ~_BV(5)
+#define CKOUT       ~_BV(6)
+#define CKDIV8      ~_BV(7)
+#define LFUSE_DEFAULT (CKSEL0 & CKSEL2 & CKSEL3 & SUT0 & CKDIV8)
+
+/* High Fuse Byte */
+#define RSTDISBL    ~_BV(0)
+#define BODLEVEL0   ~_BV(1)
+#define BODLEVEL1   ~_BV(2)
+#define BODLEVEL2   ~_BV(3)
+#define WDTON       ~_BV(4)
+#define SPIEN       ~_BV(5)
+#define EESAVE      ~_BV(6)
+#define DWEN        ~_BV(7)
+#define HFUSE_DEFAULT (SPIEN)
+
+/* Extended Fuse Byte */
+#define SELFPRGEN   ~_BV(0)
+#define EFUSE_DEFAULT (0xFF)
+
+
+/* Lock Bits */
+#define __LOCK_BITS_EXIST
+
+
 #endif  /* _AVR_IOTN2313_H_ */
