@@ -1,4 +1,4 @@
-/* Copyright (c) 2004 Eric B. Weddington
+/* Copyright (c) 2004,2005 Eric B. Weddington
    All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iotn26.h,v 1.7.2.4 2005/07/19 15:02:13 aesok Exp $ */
+/* $Id: iotn26.h,v 1.14.2.1 2007/12/12 04:39:28 arcanum Exp $ */
 
 /* avr/iotn26.h - definitions for ATtiny26 */
 
@@ -292,17 +292,50 @@
 
 /* Interrupt vectors */
 /* Interrupt vector 0 is the reset vector. */
-#define SIG_INTERRUPT0          _VECTOR(1)
-#define SIG_PIN_CHANGE          _VECTOR(2)
-#define SIG_OUTPUT_COMPARE1A    _VECTOR(3)
-#define SIG_OUTPUT_COMPARE1B    _VECTOR(4)
-#define SIG_OVERFLOW1           _VECTOR(5)
-#define SIG_OVERFLOW0           _VECTOR(6)
-#define SIG_USI_START           _VECTOR(7)
-#define SIG_USI_OVERFLOW        _VECTOR(8)
-#define SIG_EEPROM_READY        _VECTOR(9)
-#define SIG_ANA_COMP            _VECTOR(10)
-#define SIG_ADC                 _VECTOR(11)
+/* External Interrupt 0 */
+#define INT0_vect			_VECTOR(1)
+#define SIG_INTERRUPT0			_VECTOR(1)
+
+/* External Interrupt Request 0 */
+#define IO_PINS_vect			_VECTOR(2)
+#define SIG_PIN_CHANGE			_VECTOR(2)
+
+/* Timer/Counter1 Compare Match 1A */
+#define TIMER1_CMPA_vect		_VECTOR(3)
+#define SIG_OUTPUT_COMPARE1A		_VECTOR(3)
+
+/* Timer/Counter1 Compare Match 1B */
+#define TIMER1_CMPB_vect		_VECTOR(4)
+#define SIG_OUTPUT_COMPARE1B		_VECTOR(4)
+
+/* Timer/Counter1 Overflow */
+#define TIMER1_OVF1_vect		_VECTOR(5)
+#define SIG_OVERFLOW1			_VECTOR(5)
+
+/* Timer/Counter0 Overflow */
+#define TIMER0_OVF0_vect		_VECTOR(6)
+#define SIG_OVERFLOW0			_VECTOR(6)
+
+/* USI Start */
+#define USI_STRT_vect			_VECTOR(7)
+#define SIG_USI_START			_VECTOR(7)
+
+/* USI Overflow */
+#define USI_OVF_vect			_VECTOR(8)
+#define SIG_USI_OVERFLOW		_VECTOR(8)
+
+/* EEPROM Ready */
+#define EE_RDY_vect			_VECTOR(9)
+#define SIG_EEPROM_READY		_VECTOR(9)
+
+/* Analog Comparator */
+#define ANA_COMP_vect			_VECTOR(10)
+#define SIG_ANA_COMP			_VECTOR(10)
+#define SIG_COMPARATOR			_VECTOR(10)
+
+/* ADC Conversion Complete */
+#define ADC_vect			_VECTOR(11)
+#define SIG_ADC				_VECTOR(11)
 
 #define _VECTORS_SIZE 24
 
@@ -313,4 +346,33 @@
 #define E2END       0x7F
 #define FLASHEND    0x07FF
 
+
+/* Fuses */
+
+#define FUSE_MEMORY_SIZE 2
+
+/* Low Fuse Byte */
+#define CKSEL0      ~_BV(0)
+#define CKSEL1      ~_BV(1)
+#define CKSEL2      ~_BV(2)
+#define CKSEL3      ~_BV(3)
+#define SUT0        ~_BV(4)
+#define SUT1        ~_BV(5)
+#define CKOPT       ~_BV(6)
+#define PLLCK    ~_BV(7)
+#define LFUSE_DEFAULT (CKSEL1 & CKSEL2)
+
+/* High Fuse Byte */
+#define BODEN       ~_BV(0)
+#define BODLEVEL    ~_BV(1)
+#define EESAVE      ~_BV(2)
+#define SPIEN       ~_BV(3)
+#define RSTDISBL    ~_BV(4)
+#define HFUSE_DEFAULT (SPIEN)
+
+
+/* Lock Bits */
+#define __LOCK_BITS_EXIST
+
+
 #endif  /* _AVR_IOTN26_H_ */
