@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iotn28.h,v 1.5.2.1 2005/07/19 15:02:13 aesok Exp $ */
+/* $Id: iotn28.h,v 1.8.2.1 2007/12/12 04:39:29 arcanum Exp $ */
 
 /* avr/iotn28.h - definitions for ATtiny28 */
 
@@ -91,11 +91,25 @@
 
 /* Interrupt vectors */
 
-#define SIG_INTERRUPT0		_VECTOR(1)
-#define SIG_INTERRUPT1		_VECTOR(2)
-#define SIG_PIN			_VECTOR(3)
-#define SIG_OVERFLOW0		_VECTOR(4)
-#define SIG_COMPARATOR		_VECTOR(5)
+/* External Interrupt 0 */
+#define INT0_vect			_VECTOR(1)
+#define SIG_INTERRUPT0			_VECTOR(1)
+
+/* External Interrupt 1 */
+#define INT1_vect			_VECTOR(2)
+#define SIG_INTERRUPT1			_VECTOR(2)
+
+/* Low-level Input on Port B */
+#define LOWLEVEL_IO_PINS_vect		_VECTOR(3)
+#define SIG_PIN				_VECTOR(3)
+
+/* Timer/Counter0 Overflow */
+#define TIMER0_OVF_vect			_VECTOR(4)
+#define SIG_OVERFLOW0			_VECTOR(4)
+
+/* Analog Comparator */
+#define ANA_COMP_vect			_VECTOR(5)
+#define SIG_COMPARATOR			_VECTOR(5)
 
 #define _VECTORS_SIZE 12
 
@@ -233,4 +247,22 @@
 #define E2END		0x0
 #define FLASHEND	0x7FF
 
+
+/* Fuses */
+
+#define FUSE_MEMORY_SIZE 1
+
+/* Fuse Byte */
+#define CKSEL0      ~_BV(0)
+#define CKSEL1      ~_BV(1)
+#define CKSEL2      ~_BV(2)
+#define CKSEL3      ~_BV(3)
+#define INTCAP      ~_BV(4)
+#define FUSE_DEFAULT (CKSEL0 & CKSEL2 & CKSEL3)
+
+
+/* Lock Bits */
+#define __LOCK_BITS_EXIST
+
+
 #endif /* _AVR_IOTN28_H_ */
