@@ -29,7 +29,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: wdt.h,v 1.22.2.14 2007/05/13 20:36:04 aesok Exp $ */
+/* $Id: wdt.h,v 1.22.2.21 2007/11/29 22:37:43 arcanum Exp $ */
 
 /*
    avr/wdt.h - macros for AVR watchdog timer
@@ -70,7 +70,7 @@
     #include <stdint.h>
     #include <avr/wdt.h>
 
-    uint8_t mcusr_mirror;
+    uint8_t mcusr_mirror _attribute_ ((section (".noinit")));
 
     void get_mcusr(void) \
       __attribute__((naked)) \
@@ -117,30 +117,62 @@
 
 
 #if defined(__AVR_AT90CAN128__) \
-|| defined(__AVR_AT90CAN32__) || defined(__AVR_AT90CAN64__) \
-|| defined(__AVR_AT90USB82__) || defined(__AVR_AT90USB162__) \
-|| defined(__AVR_AT90USB646__) || defined(__AVR_AT90USB647__) \
-|| defined(__AVR_AT90USB1286__) || defined(__AVR_AT90USB1287__) \
-|| defined(__AVR_ATmega48__) || defined(__AVR_ATmega88__) \
+|| defined(__AVR_AT90CAN32__) \
+|| defined(__AVR_AT90CAN64__) \
+|| defined(__AVR_AT90USB82__) \
+|| defined(__AVR_AT90USB162__) \
+|| defined(__AVR_AT90USB646__) \
+|| defined(__AVR_AT90USB647__) \
+|| defined(__AVR_AT90USB1286__) \
+|| defined(__AVR_AT90USB1287__) \
+|| defined(__AVR_ATmega48__) \
+|| defined(__AVR_ATmega48P__) \
+|| defined(__AVR_ATmega88__) \
+|| defined(__AVR_ATmega88P__) \
+|| defined(__AVR_ATmega1284P__) \
 || defined(__AVR_ATmega164P__) \
-|| defined(__AVR_ATmega165__) || defined(__AVR_ATmega165P__) \
+|| defined(__AVR_ATmega165__) \
+|| defined(__AVR_ATmega165P__) \
 || defined(__AVR_ATmega168__) \
-|| defined(__AVR_ATmega169__) || defined(__AVR_ATmega169P__) \
+|| defined(__AVR_ATmega168P__) \
+|| defined(__AVR_ATmega328P__) \
+|| defined(__AVR_ATmega169__) \
+|| defined(__AVR_ATmega169P__) \
 || defined(__AVR_ATmega324P__) \
-|| defined(__AVR_ATmega325__) || defined(__AVR_ATmega3250__) \
-|| defined(__AVR_ATmega329__) || defined(__AVR_ATmega3290__) \
-|| defined(__AVR_ATmega325P__) || defined(__AVR_ATmega3250P__) \
-|| defined(__AVR_ATmega329P__) || defined(__AVR_ATmega3290P__) \
+|| defined(__AVR_ATmega325__) \
+|| defined(__AVR_ATmega3250__) \
+|| defined(__AVR_ATmega329__) \
+|| defined(__AVR_ATmega3290__) \
+|| defined(__AVR_ATmega325P__) \
+|| defined(__AVR_ATmega3250P__) \
+|| defined(__AVR_ATmega329P__) \
+|| defined(__AVR_ATmega3290P__) \
 || defined(__AVR_ATmega406__) \
 || defined(__AVR_ATmega640__) \
-|| defined(__AVR_ATmega644__) || defined(__AVR_ATmega644P__) \
-|| defined(__AVR_ATmega645__) || defined(__AVR_ATmega6450__) \
-|| defined(__AVR_ATmega649__) || defined(__AVR_ATmega6490__) \
-|| defined(__AVR_ATmega1280__) || defined(__AVR_ATmega1281__) \
-|| defined(__AVR_ATmega2560__) || defined(__AVR_ATmega2561__) \
-|| defined(__AVR_ATmega8HVA__) || defined(__AVR_ATmega16HVA__) \
+|| defined(__AVR_ATmega644__) \
+|| defined(__AVR_ATmega644P__) \
+|| defined(__AVR_ATmega645__) \
+|| defined(__AVR_ATmega6450__) \
+|| defined(__AVR_ATmega649__) \
+|| defined(__AVR_ATmega6490__) \
+|| defined(__AVR_ATmega1280__) \
+|| defined(__AVR_ATmega1281__) \
+|| defined(__AVR_ATmega2560__) \
+|| defined(__AVR_ATmega2561__) \
+|| defined(__AVR_ATmega8HVA__) \
+|| defined(__AVR_ATmega16HVA__) \
+|| defined(__AVR_ATmega32HVB__) \
 || defined(__AVR_AT90PWM1__) \
-|| defined(__AVR_AT90PWM2__) || defined(__AVR_AT90PWM3__)
+|| defined(__AVR_AT90PWM2__) \
+|| defined(__AVR_AT90PWM2B__) \
+|| defined(__AVR_AT90PWM3__) \
+|| defined(__AVR_AT90PWM3B__) \
+|| defined(__AVR_AT90PWM216__) \
+|| defined(__AVR_AT90PWM316__) \
+|| defined(__AVR_ATtiny48__) \
+|| defined(__AVR_ATtiny88__)
+
+
  
 #define _wdt_write(value)   \
     __asm__ __volatile__ (  \
@@ -287,13 +319,15 @@ __asm__ __volatile__ (  \
     ATtiny25, ATtiny45, ATtiny85, 
     ATtiny261, ATtiny461, ATtiny861, 
     ATmega48, ATmega88, ATmega168,
+    ATmega48P, ATmega88P, ATmega168P, ATmega328P,
     ATmega164P, ATmega324P, ATmega644P, ATmega644,
     ATmega640, ATmega1280, ATmega1281, ATmega2560, ATmega2561,
-    ATmega8HVA, ATmega16HVA,
-    ATmega406,
-    AT90PWM1, AT90PWM2, AT90PWM3,
+    ATmega8HVA, ATmega16HVA, ATmega32HVB,
+    ATmega406, ATmega1284P,
+    AT90PWM1, AT90PWM2, AT90PWM2B, AT90PWM3, AT90PWM3B, AT90PWM216, AT90PWM316
     AT90USB82, AT90USB162,
-    AT90USB646, AT90USB647, AT90USB1286, AT90USB1287.
+    AT90USB646, AT90USB647, AT90USB1286, AT90USB1287,
+    ATtiny48, ATtiny88.
     */
 #define WDTO_4S     8
 
@@ -305,13 +339,15 @@ __asm__ __volatile__ (  \
     ATtiny25, ATtiny45, ATtiny85, 
     ATtiny261, ATtiny461, ATtiny861, 
     ATmega48, ATmega88, ATmega168,
+    ATmega48P, ATmega88P, ATmega168P, ATmega328P,
     ATmega164P, ATmega324P, ATmega644P, ATmega644,
     ATmega640, ATmega1280, ATmega1281, ATmega2560, ATmega2561,
-    ATmega8HVA, ATmega16HVA,
-    ATmega406,
-    AT90PWM1, AT90PWM2, AT90PWM3,
+    ATmega8HVA, ATmega16HVA, ATmega32HVB,
+    ATmega406, ATmega1284P,
+    AT90PWM1, AT90PWM2, AT90PWM2B, AT90PWM3, AT90PWM3B, AT90PWM216, AT90PWM316
     AT90USB82, AT90USB162,
-    AT90USB646, AT90USB647, AT90USB1286, AT90USB1287.
+    AT90USB646, AT90USB647, AT90USB1286, AT90USB1287,
+    ATtiny48, ATtiny88.
     */
 #define WDTO_8S     9
 
